// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Copy the test info into the assignment's description.
 * The test info is the contents of the 'test_question' element (plus an <img>
 * if the 'test_image' element is set) returned by the endpoint
 * .../console/essay/test-info/<test_link>.  See step 3 here for further
 * details: https://virtualwritingtutor.com/essay-check-api
 * @module    assignsubmission_vwttext/copy_description
 * @package   assignsubmission_vwttext
 * @copyright 2023 Bokomaru Publications
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
import {getDescription} from './repository';
import {editor} from './editor';
import Notification from 'core/notification';
import {addIconToContainerRemoveOnCompletion} from 'core/loadingicon';

export const copyDescription = async() => {
    let elements = document.getElementsByName('assignsubmission_vwttext_tasklink');
    const essays = elements[0];
    essays.disabled = true;

    elements = document.getElementsByName('assignsubmission_vwttext_testlink_select');
    const test = elements[0];
    test.disabled = true;
    const testLink = test.value;

    elements = document.getElementsByName('assignsubmission_vwttext_copy');
    const copy = elements[0];
    copy.disabled = true;

    elements = document.getElementsByName('assignsubmission_vwttext_copy');
    const loadingDiv = elements[0].parentNode;

    try {
        const promise = getDescription(testLink).fail(Notification.exception);
        addIconToContainerRemoveOnCompletion(loadingDiv, promise);
        const response = await promise;

        const img = response.test_image ?
                    '<p><img src="' + response.test_image + '" '
                    + 'alt="' + response.test_name + '" width="400"/></p>\n"'
                    : '';

        editor.setDescription(img + response.test_question);
    } catch(e) {
        // Error should be displayed to user by .fail() above.
    }

    test.disabled = false;
    essays.disabled = false;
    copy.disabled = false;
};
