// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

import {addIconToContainer} from 'core/loadingicon';
import {get_string as getString} from 'core/str';

/**
 * Client-side script for student edit submission page
 * (mod/assign/view.php?id=<ID>&action=editsubmission).
 * @module    assignsubmission_vwttext/editsubmission
 * @package   assignsubmission_vwttext
 * @copyright 2023 Bokomaru Publications
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
export const init = async() => {
    let elements = document.getElementsByName('submitbutton');
    let form = elements[0].form;
    let gettingEvaluation = await getString('gettingevaluation', 'assignsubmission_vwttext');

    // When submission's "Save changes" button is clicked:
    //   1. Disable "Automated evaluation" button
    //   2. Show "Getting evaluation..." and loading icon.
    let saveChangesClicked = function(event) {
        if (event.submitter.name === 'cancel') {
            return;
        }

        let elements = document.getElementsByName('assignsubmission_vwttext_evaluate');

        if (elements.length === 1) {
            // Disable optional "Automated evaluation" button
            elements[0].disabled = true;
        }

        elements = document.getElementsByName('assignsubmission_vwttext_loading');
        const loadingDiv = elements[0];
        loadingDiv.innerHTML = gettingEvaluation;
        addIconToContainer(loadingDiv);
    };

    form.addEventListener('submit', saveChangesClicked);
};
