// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Update the second "Evaluation selector" drop-down list on the assignment
 * settings page.
 * @module    assignsubmission_vwttext/select
 * @package   assignsubmission_vwttext
 * @copyright 2023 Bokomaru Publications
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
import {getTaskList} from './repository';
import Notification from 'core/notification';
import {addIconToContainerRemoveOnCompletion} from 'core/loadingicon';

// Call assignsubmission_vwttext_get_task_list to get the tasks for the selected
// essay type and populate the drop-down list with those tasks.
export const taskChanged = async() => {
    let elements = document.getElementsByName('assignsubmission_vwttext_tasklink');
    const essaysSelect = elements[0];
    essaysSelect.disabled = true;
    const taskLink = essaysSelect.value;

    elements = document.getElementsByName('assignsubmission_vwttext_testlink_select');
    const tasksSelect = elements[0];
    tasksSelect.disabled = true;

    elements = document.getElementsByName('assignsubmission_vwttext_copy');
    const copyButton = elements[0];
    copyButton.disabled = true;
    elements = document.getElementsByName('assignsubmission_vwttext_testlink_select');
    const loadingDiv = elements[0].parentNode;

    try {
        const promise = getTaskList(taskLink).fail(Notification.exception);
        addIconToContainerRemoveOnCompletion(loadingDiv, promise);
        const response = await promise;
        tasksSelect.options.length = 0;
        response.forEach(task => tasksSelect.appendChild(new Option(task.test_name, task.test_link)));

        // Initialise hidden field's value with first element
        elements = document.getElementsByName('assignsubmission_vwttext_testlink');
        const testLink = elements[0];
        testLink.value = response[0].test_link;
    } catch(e) {
        // Error should be displayed to user by .fail() above.
    }

    essaysSelect.disabled = false;
    tasksSelect.disabled = false;
    copyButton.disabled = false;
};

// Populate hidden field with value of second "Evaluation selector" drop-down
// list.  This is because we dynamically change the second list's values based
// on the first list's selection.  But the Moodle form API validates a drop-
// down list's selection against the initial values (defined in
// assign_submission_vwttext->get_settings()) so any subsequently added value
// gets removed for assign_submission_vwttext->save_settings().  So we use the
// hidden field to see that value.
export const testChanged = () => {
    let elements = document.getElementsByName('assignsubmission_vwttext_testlink_select');
    const testlink = elements[0].value;
    elements = document.getElementsByName('assignsubmission_vwttext_testlink');
    elements[0].value = testlink;
};
