<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * @package   assignfeedback_vwttext
 * @copyright 2023 Bokomaru Publications
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

namespace assignsubmission_vwttext;

/**
 * Exception during request to API call.
 */
class api_exception extends \moodle_exception {
    /**
     * If API provides an error message then this can be passed in the 'error'
     * property of the curl subclass representing the API.
     * @param curl $curl Subclass of curl representing an API.
     * @param string $response Any response body to the HTTP request to the
     * API.
     */
    function __construct(\curl $curl, string $response) {
        if (!empty($curl->error)) {
            parent::__construct('apierrormessage', 'assignsubmission_vwttext', '', $curl->error);
        } else {
            $a = array('error' => $response, 'url' => $curl->info['url'], 'httpstatus' => $curl->info['http_code']);
            parent::__construct('apierror', 'assignsubmission_vwttext', '', $a);
        }
    }
}
